@@ -160,7 +160,7 @@ def main(args=None):
 # C.1) Export to netcdf
 # C.1.i) Netcdf filename
             try:
-                fname = nc_name(metadata[i], dt_start_arr[i], exts[i])
+                fname = nc_name(metadata[i], exts[i])
             except Exception as e:
                 logger.error("Error while creating the netcdf filename ")
                 sys.exit(9)  
@@ -168,8 +168,8 @@ def main(args=None):
             
 # C.1.ii) Netcdf file        
             try:
-                dir_out = cfg.scc['output-dir']
-                geom_dts = export_nc(geom, metadata[i], alphas[i], exts, 
+                dir_out = os.path.join(cfg.scc['output-dir'],meas_id)
+                geom_dts = export_nc(geom, metadata[i], alphas[i], exts[i], 
                                      det_lims[i], fname, dir_out)
             except Exception as e:
                 logger.error("Error while creating the netcdf files ")
